@@ -7,6 +7,7 @@ import json
 
 from . import usage, version
 from .retriever import retrieve_model, retrieve_model_from_file, retrieve_raw
+from .related import get_related
 
 
 def _arg_parser():
@@ -46,6 +47,10 @@ def _arg_parser():
         default="all",
     )
 
+    parser.add_argument(
+        "-r", "--related", help="retrieve related reference ids", action="store_true"
+    )
+
     parser.add_argument("--timeout", help="timeout", type=int)
 
     parser.add_argument("--indent", help="indentation spaces", default=None)
@@ -58,7 +63,9 @@ def _arg_parser():
 
     subparsers = parser.add_subparsers(dest="from_file")
 
-    parser_from_file = subparsers.add_parser("from_file", help="parse files to get the model")
+    parser_from_file = subparsers.add_parser(
+        "from_file", help="parse files to get the model"
+    )
 
     parser_from_file.add_argument(
         "--paths",
@@ -101,6 +108,12 @@ def main():
             timeout=args.timeout,
         )
         print(json.dumps(output, indent=args.indent))
+    elif args.related:
+        output = get_related(
+            reference_id=args.id,
+            timeout=args.timeout,
+        )
+        print(json.dumps(output, indent=args.indent))
     else:
         output = retrieve_raw(
             reference_id=args.id,
